==> haskell-colourista-0.1.0.2-138.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-colourista.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 colourista
version:              0.1.0.2
visibility:           public
id:                   colourista-0.1.0.2-IcvjUpc9Rbw706VyAKHsEE
key:                  colourista-0.1.0.2-IcvjUpc9Rbw706VyAKHsEE
license:              MPL-2.0
copyright:            2020-2022 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
homepage:             https://github.com/kowainik/colourista
synopsis:             Convenient interface for printing colourful messages
description:
    Convenient interface for printing colourful messages based on the @ansi-terminal@ library.

category:             Terminal, ANSI
abi:                  ab12db37c076d9a69a1250520247e02d
exposed:              True
exposed-modules:
    Colourista Colourista.IO Colourista.Pure Colourista.Short

import-dirs:          /usr/lib/ghc-9.6.6/site-local/colourista-0.1.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/colourista-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/colourista-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-colourista
hs-libraries:         HScolourista-0.1.0.2-IcvjUpc9Rbw706VyAKHsEE
depends:
    ansi-terminal-1.0.2-99kMoKqjfKvAwKECL4LpDt base-4.18.2.1
    bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-colourista/html/colourista.haddock
haddock-html:         /usr/share/doc/haskell-colourista/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-colourista-0.1.0.2-139-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-colourista.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 colourista
version:              0.1.0.2
visibility:           public
id:                   colourista-0.1.0.2-HTbTpLqd7UA3ymn8nCJJVI
key:                  colourista-0.1.0.2-HTbTpLqd7UA3ymn8nCJJVI
license:              MPL-2.0
copyright:            2020-2022 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
homepage:             https://github.com/kowainik/colourista
synopsis:             Convenient interface for printing colourful messages
description:
    Convenient interface for printing colourful messages based on the @ansi-terminal@ library.

category:             Terminal, ANSI
abi:                  6fc2ab1fa5eea45a1cc6c09056f4736b
exposed:              True
exposed-modules:
    Colourista Colourista.IO Colourista.Pure Colourista.Short

import-dirs:          /usr/lib/ghc-9.6.6/site-local/colourista-0.1.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/colourista-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/colourista-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-colourista
hs-libraries:         HScolourista-0.1.0.2-HTbTpLqd7UA3ymn8nCJJVI
depends:
    ansi-terminal-1.0.2-8AlL5ra8Vsx5bOLC8RDvPh base-4.18.2.1
    bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-colourista/html/colourista.haddock
haddock-html:         /usr/share/doc/haskell-colourista/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
